CircuitsFT232H.USB.Descriptor (circuits_ft232h v0.1.0)

Metadata for a single FT232H device discovered on the USB bus.

The :device field is an opaque reference handed back by the :usb library. It does not represent an open handle — it is just enough to identify the device and open it later via CircuitsFT232H.USB.open/1.

Summary

Types

t()

@type t() :: %CircuitsFT232H.USB.Descriptor{
  address: 0..255,
  bus: 0..255,
  device: :usb.device(),
  port_numbers: [0..255],
  serial: String.t() | nil,
  speed: :unknown | :low | :full | :high | :super | :super_plus
}